@@ -466,7 +466,7 @@ def new_docker_env(
     stage: Annotated[
         str,
         typer.Option(
-            "--stage", help="DVC pipeline stage name, if built in one."
+            "--stage", help="DVC pipeline stage name, deprecated."
         ),
     ] = None,
     layers: Annotated[
@@ -551,6 +551,7 @@ def new_docker_env(
         ryaml.dump(ck_info, f)
     # If we're creating a stage, do so with DVC
     if stage:
+        warn("--stage is deprecated since envs are checked at run time")
         typer.echo(f"Creating DVC stage {stage}")
         if not os.path.isfile(".dvc/config"):
             typer.echo(f"Running dvc init")
@@ -910,7 +911,7 @@ def new_publication(
             f"-pdf {template_obj.target}"
         )
         if env_name is not None:
-            cmd = f'calkit runenv -n {env_name} "{cmd}"'
+            cmd = f'calkit xenv -n {env_name} "{cmd}"'
         target_dep = os.path.join(path, template_obj.target)
         dvc_cmd = [
             "dvc",
